==> kamailio_5.1.2.orig.tar.gz: kamailio-5.1.2/src/modules/cdp/peerstatemachine.h <==
/*
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 *
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 *
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus.
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef __STATEMACHINE_H
#define __STATEMACHINE_H

#include "utils.h"
#include "peer.h"
#include "diameter.h"

int sm_process(peer *p,peer_event_t event,AAAMessage *msg,int peer_locked,int sock);

peer_event_t I_Snd_Conn_Req(peer *p);
void Cleanup(peer *p,int sock);
void Error(peer *p, int sock);
void I_Snd_CER(peer *p);
int Process_CEA(peer *p,AAAMessage *cea);
void I_Disc(peer *p);
void R_Disc(peer *p);
int Process_DWR(peer *p,AAAMessage *dwr);
void Process_DWA(peer *p,AAAMessage *dwa);
void Snd_DWR(peer *p);
void Snd_DWA(peer *p,AAAMessage *dwr,int result_code,int sock);
void Snd_DPR(peer *p);
void Snd_DPA(peer *p,AAAMessage *dpr,int result_code,int sock);
void R_Accept(peer *p,int sock);
void R_Reject(peer *p,int sock);
int Process_CER(peer *p,AAAMessage *cer);
void Snd_CEA(peer *p,AAAMessage *cer,int result_code,int sock);
int Elect(peer *p,AAAMessage *cer);

void Snd_Message(peer *p, AAAMessage *msg);
void Rcv_Process(peer *p, AAAMessage *msg);

#endif

==> kamailio_5.8.2.orig.tar.gz: kamailio-5.8.2/src/modules/cdp/peerstatemachine.h <==
/*
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 *
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 *
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus.
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef __STATEMACHINE_H
#define __STATEMACHINE_H

#include "utils.h"
#include "peer.h"
#include "diameter.h"

int sm_process(peer *p, peer_event_t event, AAAMessage *msg, int peer_locked,
		int sock);

peer_event_t I_Snd_Conn_Req(peer *p);
void Cleanup(peer *p, int sock);
void Error(peer *p, int sock);
void I_Snd_CER(peer *p);
int Process_CEA(peer *p, AAAMessage *cea);
void I_Disc(peer *p);
void R_Disc(peer *p);
int Process_DWR(peer *p, AAAMessage *dwr);
void Process_DWA(peer *p, AAAMessage *dwa);
void Snd_DWR(peer *p);
void Snd_DWA(peer *p, AAAMessage *dwr, int result_code, int sock);
void Snd_DPR(peer *p);
void Snd_DPA(peer *p, AAAMessage *dpr, int result_code, int sock);
void R_Accept(peer *p, int sock);
void R_Reject(peer *p, int sock);
int Process_CER(peer *p, AAAMessage *cer);
void Snd_CEA(peer *p, AAAMessage *cer, int result_code, int sock);
int Elect(peer *p, AAAMessage *cer);

void Snd_Message(peer *p, AAAMessage *msg);
void Rcv_Process(peer *p, AAAMessage *msg);

#endif
